@@ -478,65 +478,102 @@ class InvoicesScreen(CScreen):
         d.open()
 
 
-class RequestsScreen(CScreen):
-    kvname = 'requests'
+address_icon = {
+    'Pending' : 'atlas://gui/kivy/theming/light/important',
+    'Paid' : 'atlas://gui/kivy/theming/light/confirmed'
+}
+ 
+class AddressScreen(CScreen):
+    kvname = 'address'
     cards = {}
 
-    def get_card(self, req):
-        address = req['address']
-        timestamp = req.get('time', 0)
-        amount = req.get('amount')
-        expiration = req.get('exp', None)
-        status = req.get('status')
-        signature = req.get('sig')
-
-        ci = self.cards.get(address)
+    def get_card(self, addr, balance, is_used, label):
+        ci = self.cards.get(addr)
         if ci is None:
-            ci = Factory.RequestItem()
+            ci = Factory.AddressItem()
             ci.screen = self
-            ci.address = address
-            self.cards[address] = ci
+            ci.address = addr
+            self.cards[addr] = ci
 
-        ci.memo = self.app.wallet.get_label(address)
-        if amount:
-            status = req.get('status')
-            ci.status = request_text[status]
+        ci.memo = label
+        ci.amount = self.app.format_amount_and_units(balance)
+        request = self.app.wallet.get_payment_request(addr, self.app.electrum_config)
+        if is_used:
+            ci.status = _('Used')
+        elif request:
+            status, conf = self.app.wallet.get_request_status(addr)
+            requested_amount = request.get('amount')
+            # make sure that requested amount is > 0
+            if status == PR_PAID:
+                s = _('Request paid')
+            elif status == PR_UNPAID:
+                s = _('Request pending')
+            elif status == PR_EXPIRED:
+                s = _('Request expired')
+            else:
+                s = ''
+            ci.status = s + ': ' + self.app.format_amount_and_units(requested_amount)
         else:
-            received = self.app.wallet.get_addr_received(address)
-            ci.status = self.app.format_amount_and_units(amount)
-        ci.icon = pr_icon[status]
-        ci.amount = self.app.format_amount_and_units(amount) if amount else _('No Amount')
-        ci.date = format_time(timestamp)
+            ci.status = _('Funded') if balance>0 else _('Unused')
         return ci
 
+
     def update(self):
-        self.menu_actions = [('Show', self.do_show), ('Details', self.do_view), ('Delete', self.do_delete)]
-        requests_list = self.screen.ids.requests_container
-        requests_list.clear_widgets()
-        _list = self.app.wallet.get_sorted_requests(self.app.electrum_config) if self.app.wallet else []
-        for req in _list:
-            ci = self.get_card(req)
-            requests_list.add_widget(ci)
-        if not _list:
-            msg = _('This screen shows the list of payment requests you made.')
-            requests_list.add_widget(EmptyLabel(text=msg))
+        self.menu_actions = [('Receive', self.do_show), ('Details', self.do_view)]
+        wallet = self.app.wallet
+        _list = wallet.change_addresses if self.screen.show_change else wallet.receiving_addresses
+        search = self.screen.message
+        container = self.screen.ids.search_container
+        container.clear_widgets()
+        n = 0
+        for address in _list:
+            label = wallet.labels.get(address, '')
+            balance = sum(wallet.get_addr_balance(address))
+            is_used = wallet.is_used(address)
+            if self.screen.show_used == 1 and (balance or is_used):
+                continue
+            if self.screen.show_used == 2 and balance == 0:
+                continue
+            if self.screen.show_used == 3 and not is_used:
+                continue
+            card = self.get_card(address, balance, is_used, label)
+            if search and not self.ext_search(card, search):
+                continue
+            container.add_widget(card)
+            n += 1
+        if not n:
+            msg = _('No address matching your search')
+            container.add_widget(EmptyLabel(text=msg))
 
     def do_show(self, obj):
         self.app.show_request(obj.address)
 
     def do_view(self, obj):
         req = self.app.wallet.get_payment_request(obj.address, self.app.electrum_config)
-        status = req.get('status')
-        amount = req.get('amount')
-        address = req['address']
-        if amount:
+        if req:
+            c, u, x = self.app.wallet.get_addr_balance(obj.address)
+            balance = c + u + x
+            if balance > 0:
+                req['fund'] = balance
             status = req.get('status')
-            status = request_text[status]
-        else:
-            received_amount = self.app.wallet.get_addr_received(address)
-            status = self.app.format_amount_and_units(received_amount)
+            amount = req.get('amount')
+            address = req['address']
+            if amount:
+                status = req.get('status')
+                status = request_text[status]
+            else:
+                received_amount = self.app.wallet.get_addr_received(address)
+                status = self.app.format_amount_and_units(received_amount)
+            self.app.show_pr_details(req, status, False)
 
-        self.app.show_pr_details(req, status, False)
+        else:
+            req = { 'address': obj.address, 'status' : obj.status }
+            status = obj.status
+            c, u, x = self.app.wallet.get_addr_balance(obj.address)
+            balance = c + u + x
+            if balance > 0:
+                req['fund'] = balance
+            self.app.show_addr_details(req, status)
 
     def do_delete(self, obj):
         from .dialogs.question import Question
@@ -547,6 +584,9 @@ class RequestsScreen(CScreen):
         d = Question(_('Delete request?'), cb)
         d.open()
 
+    def ext_search(self, card, search):
+        return card.memo.find(search) >= 0 or card.amount.find(search) >= 0
+
 
 
 
